@@ -3,6 +3,7 @@ package main
 import (
 	"encoding/json"
 	"fmt"
+	"os/exec"
 	"strconv"
 	"strings"
 	"time"
@@ -14,7 +15,7 @@ import (
 type CommandType TokenType
 
 // CommandTypes is a list of the available commands that can be executed.
-var CommandTypes = []CommandType{
+var CommandTypes = []CommandType{ //nolint: deadcode
 	BACKSPACE,
 	CTRL,
 	DOWN,
@@ -28,6 +29,7 @@ var CommandTypes = []CommandType{
 	SLEEP,
 	SPACE,
 	HIDE,
+	REQUIRE,
 	SHOW,
 	TAB,
 	TYPE,
@@ -59,6 +61,7 @@ var CommandFuncs = map[CommandType]CommandFunc{
 	TAB:       ExecuteKey(input.Tab),
 	ESCAPE:    ExecuteKey(input.Escape),
 	HIDE:      ExecuteHide,
+	REQUIRE:   ExecuteRequire,
 	SHOW:      ExecuteShow,
 	SET:       ExecuteSet,
 	OUTPUT:    ExecuteOutput,
@@ -106,8 +109,8 @@ func ExecuteNoop(c Command, v *VHS) {}
 func ExecuteKey(k input.Key) CommandFunc {
 	return func(c Command, v *VHS) {
 		typingSpeed, err := time.ParseDuration(c.Options)
-		if err == nil {
-			v.browser.SlowMotion(typingSpeed)
+		if err != nil {
+			typingSpeed = v.Options.TypingSpeed
 		}
 		repeat, err := strconv.Atoi(c.Args)
 		if err != nil {
@@ -115,8 +118,8 @@ func ExecuteKey(k input.Key) CommandFunc {
 		}
 		for i := 0; i < repeat; i++ {
 			_ = v.Page.Keyboard.Type(k)
+			time.Sleep(typingSpeed)
 		}
-		v.browser.SlowMotion(v.Options.TypingSpeed)
 	}
 }
 
@@ -134,13 +137,20 @@ func ExecuteCtrl(c Command, v *VHS) {
 
 // ExecuteHide is a CommandFunc that starts or stops the recording of the vhs.
 func ExecuteHide(c Command, v *VHS) {
-	v.browser.SlowMotion(0)
 	v.PauseRecording()
 }
 
+// ExecuteRequire is a CommandFunc that checks if all the binaries mentioned in the
+// Require command are present. If not, it exits with a non-zero error.
+func ExecuteRequire(c Command, v *VHS) {
+	_, err := exec.LookPath(c.Args)
+	if err != nil {
+		v.Errors = append(v.Errors, err)
+	}
+}
+
 // ExecuteShow is a CommandFunc that resumes the recording of the vhs.
 func ExecuteShow(c Command, v *VHS) {
-	v.browser.SlowMotion(v.Options.TypingSpeed)
 	v.ResumeRecording()
 }
 
@@ -157,8 +167,8 @@ func ExecuteSleep(c Command, v *VHS) {
 // ExecuteType types the argument string on the running instance of vhs.
 func ExecuteType(c Command, v *VHS) {
 	typingSpeed, err := time.ParseDuration(c.Options)
-	if err == nil {
-		v.browser.SlowMotion(typingSpeed)
+	if err != nil {
+		typingSpeed = v.Options.TypingSpeed
 	}
 	for _, r := range c.Args {
 		k, ok := keymap[r]
@@ -168,8 +178,8 @@ func ExecuteType(c Command, v *VHS) {
 			_ = v.Page.MustElement("textarea").Input(string(r))
 			v.Page.MustWaitIdle()
 		}
+		time.Sleep(typingSpeed)
 	}
-	v.browser.SlowMotion(v.Options.TypingSpeed)
 }
 
 // ExecuteOutput applies the output on the vhs videos.
@@ -202,6 +212,8 @@ var Settings = map[string]CommandFunc{
 	"Theme":         ExecuteSetTheme,
 	"TypingSpeed":   ExecuteSetTypingSpeed,
 	"Width":         ExecuteSetWidth,
+	"Shell":         ExecuteSetShell,
+	"LoopOffset":    ExecuteLoopOffset,
 }
 
 // ExecuteSet applies the settings on the running vhs specified by the
@@ -239,11 +251,21 @@ func ExecuteSetWidth(c Command, v *VHS) {
 	v.Options.Video.Width, _ = strconv.Atoi(c.Args)
 }
 
+// ExecuteSetShell applies the shell on the vhs.
+func ExecuteSetShell(c Command, v *VHS) {
+	if s, ok := Shells[c.Args]; ok {
+		v.Options.Shell = s
+	} else {
+		v.Options.Shell.Prompt = ""
+		v.Options.Shell.Command = c.Args
+	}
+}
+
 const bitSize = 64
 const base = 10
 
-// ExecuteSetLetterSpacing applies letter spacing (also known as tracking) on the
-// vhs.
+// ExecuteSetLetterSpacing applies letter spacing (also known as tracking) on
+// the vhs.
 func ExecuteSetLetterSpacing(c Command, v *VHS) {
 	letterSpacing, _ := strconv.ParseFloat(c.Args, bitSize)
 	v.Options.LetterSpacing = letterSpacing
@@ -259,13 +281,15 @@ func ExecuteSetLineHeight(c Command, v *VHS) {
 
 // ExecuteSetTheme applies the theme on the vhs.
 func ExecuteSetTheme(c Command, v *VHS) {
-	err := json.Unmarshal([]byte(c.Args), &v.Options.Theme)
+	var err error
+	v.Options.Theme, err = getTheme(c.Args)
 	if err != nil {
-		fmt.Println(err)
-		v.Options.Theme = DefaultTheme
+		v.Errors = append(v.Errors, err)
 		return
 	}
-	_, _ = v.Page.Eval(fmt.Sprintf("() => term.options.theme = %s", c.Args))
+
+	bts, _ := json.Marshal(v.Options.Theme)
+	_, _ = v.Page.Eval(fmt.Sprintf("() => term.options.theme = %s", string(bts)))
 	v.Options.Video.BackgroundColor = v.Options.Theme.Background
 }
 
@@ -276,7 +300,6 @@ func ExecuteSetTypingSpeed(c Command, v *VHS) {
 		return
 	}
 	v.Options.TypingSpeed = typingSpeed
-	v.browser.SlowMotion(typingSpeed)
 }
 
 // ExecuteSetPadding applies the padding on the vhs.
@@ -301,3 +324,32 @@ func ExecuteSetPlaybackSpeed(c Command, v *VHS) {
 	}
 	v.Options.Video.PlaybackSpeed = playbackSpeed
 }
+
+// ExecuteLoopOffset applies the loop offset option on the vhs.
+func ExecuteLoopOffset(c Command, v *VHS) {
+	loopOffset, err := strconv.ParseFloat(strings.TrimRight(c.Args, "%"), bitSize)
+	if err != nil {
+		return
+	}
+	v.Options.LoopOffset = loopOffset
+}
+
+func getTheme(s string) (Theme, error) {
+	if strings.TrimSpace(s) == "" {
+		return DefaultTheme, nil
+	}
+	switch s[0] {
+	case '{':
+		return getJSONTheme(s)
+	default:
+		return findTheme(s)
+	}
+}
+
+func getJSONTheme(s string) (Theme, error) {
+	var t Theme
+	if err := json.Unmarshal([]byte(s), &t); err != nil {
+		return DefaultTheme, fmt.Errorf("invalid `Set Theme %q: %w`", s, err)
+	}
+	return t, nil
+}
