@@ -1,10 +1,10 @@
 package main
 
 import (
-	"errors"
+	"context"
 	"fmt"
 	"io"
-	"strings"
+	"log"
 )
 
 // EvaluatorOption is a function that can be used to modify the VHS instance.
@@ -12,30 +12,23 @@ type EvaluatorOption func(*VHS)
 
 // Evaluate takes as input a tape string, an output writer, and an output file
 // and evaluates all the commands within the tape string and produces a GIF.
-func Evaluate(tape string, out io.Writer, opts ...EvaluatorOption) error {
+func Evaluate(ctx context.Context, tape string, out io.Writer, opts ...EvaluatorOption) []error {
 	l := NewLexer(tape)
 	p := NewParser(l)
 
 	cmds := p.Parse()
 	errs := p.Errors()
 	if len(errs) != 0 || len(cmds) == 0 {
-		lines := strings.Split(tape, "\n")
-		for _, err := range errs {
-			fmt.Fprint(out, LineNumber(err.Token.Line))
-			fmt.Fprintln(out, lines[err.Token.Line-1])
-			fmt.Fprint(out, strings.Repeat(" ", err.Token.Column+ErrorColumnOffset))
-			fmt.Fprintln(out, Underline(len(err.Token.Literal)), err.Msg)
-			fmt.Fprintln(out)
-		}
-		return errors.New("parse error")
+		return []error{InvalidSyntaxError{errs}}
 	}
 
 	v := New()
+	defer func() { _ = v.close() }()
 
 	// Run Output and Set commands as they only modify options on the VHS instance.
 	var offset int
 	for i, cmd := range cmds {
-		if cmd.Type == SET || cmd.Type == OUTPUT {
+		if cmd.Type == SET || cmd.Type == OUTPUT || cmd.Type == REQUIRE {
 			fmt.Fprintln(out, cmd.Highlight(false))
 			cmd.Execute(&v)
 		} else {
@@ -44,6 +37,16 @@ func Evaluate(tape string, out io.Writer, opts ...EvaluatorOption) error {
 		}
 	}
 
+	video := v.Options.Video
+	minDimension := video.Padding + video.Padding
+	if video.Height < minDimension || video.Width < minDimension {
+		v.Errors = append(v.Errors, fmt.Errorf("height and width must be greater than %d", minDimension))
+	}
+
+	if len(v.Errors) > 0 {
+		return v.Errors
+	}
+
 	// Setup the terminal session so we can start executing commands.
 	v.Setup()
 
@@ -62,21 +65,42 @@ func Evaluate(tape string, out io.Writer, opts ...EvaluatorOption) error {
 	}
 
 	// Begin recording frames as we are now in a recording state.
-	v.Record()
+	ctx, cancel := context.WithCancel(ctx)
+	ch := v.Record(ctx)
 
-	defer v.Cleanup()
+	// Clean up temporary files at the end.
+	defer func() { _ = v.Cleanup() }()
+
+	teardown := func() {
+		// Stop recording frames.
+		cancel()
+		// Read from channel to ensure recorder is done.
+		<-ch
+	}
+
+	// Log errors from the recording process.
+	go func() {
+		for err := range ch {
+			log.Print(err.Error())
+		}
+	}()
 
 	for _, cmd := range cmds[offset:] {
+		if ctx.Err() != nil {
+			teardown()
+			return []error{ctx.Err()}
+		}
+
 		// When changing the FontFamily, FontSize, LineHeight, Padding
 		// The xterm.js canvas changes dimensions and causes FFMPEG to not work
 		// correctly (specifically) with palettegen.
-		// It will be possible to change settings on the fly in the future, but it is currently not
-		// as it does not result in a proper render of the GIF as the frame sequence
-		// will change dimensions. This is fixable.
+		// It will be possible to change settings on the fly in the future, but
+		// it is currently not as it does not result in a proper render of the
+		// GIF as the frame sequence will change dimensions. This is fixable.
 		//
 		// We should remove if isSetting statement.
 		isSetting := cmd.Type == SET && cmd.Options != "TypingSpeed"
-		if isSetting {
+		if isSetting || cmd.Type == REQUIRE {
 			fmt.Fprintln(out, cmd.Highlight(true))
 			continue
 		}
@@ -96,5 +120,9 @@ func Evaluate(tape string, out io.Writer, opts ...EvaluatorOption) error {
 		opt(&v)
 	}
 
+	teardown()
+	if err := v.Render(); err != nil {
+		return []error{err}
+	}
 	return nil
 }
