@@ -102,6 +102,9 @@ func TestLexTapeFile(t *testing.T) {
 		{STRING, "examples/fixtures/all.webm"},
 		{COMMENT, " Settings:"},
 		{SET, "Set"},
+		{SHELL, "Shell"},
+		{STRING, "fish"},
+		{SET, "Set"},
 		{FONT_SIZE, "FontSize"},
 		{NUMBER, "22"},
 		{SET, "Set"},
@@ -123,6 +126,9 @@ func TestLexTapeFile(t *testing.T) {
 		{THEME, "Theme"},
 		{JSON, "{ \"name\": \"Whimsy\", \"black\": \"#535178\", \"red\": \"#ef6487\", \"green\": \"#5eca89\", \"yellow\": \"#fdd877\", \"blue\": \"#65aef7\", \"purple\": \"#aa7ff0\", \"cyan\": \"#43c1be\", \"white\": \"#ffffff\", \"brightBlack\": \"#535178\", \"brightRed\": \"#ef6487\", \"brightGreen\": \"#5eca89\", \"brightYellow\": \"#fdd877\", \"brightBlue\": \"#65aef7\", \"brightPurple\": \"#aa7ff0\", \"brightCyan\": \"#43c1be\", \"brightWhite\": \"#ffffff\", \"background\": \"#29283b\", \"foreground\": \"#b3b0d6\", \"selectionBackground\": \"#3d3c58\", \"cursorColor\": \"#b3b0d6\" }"},
 		{SET, "Set"},
+		{THEME, "Theme"},
+		{STRING, "Catppuccin Mocha"},
+		{SET, "Set"},
 		{PADDING, "Padding"},
 		{NUMBER, "50"},
 		{SET, "Set"},
@@ -134,6 +140,13 @@ func TestLexTapeFile(t *testing.T) {
 		{SET, "Set"},
 		{TYPING_SPEED, "TypingSpeed"},
 		{NUMBER, ".1"},
+		{SET, "Set"},
+		{LOOP_OFFSET, "LoopOffset"},
+		{NUMBER, "60.4"},
+		{SET, "Set"},
+		{LOOP_OFFSET, "LoopOffset"},
+		{NUMBER, "20.99"},
+		{PERCENT, "%"},
 		{COMMENT, " Sleep:"},
 		{SLEEP, "Sleep"},
 		{NUMBER, "1"},
@@ -146,8 +159,6 @@ func TestLexTapeFile(t *testing.T) {
 		{NUMBER, "0.5"},
 		{COMMENT, " Type:"},
 		{TYPE, "Type"},
-		{STRING, "All"},
-		{TYPE, "Type"},
 		{AT, "@"},
 		{NUMBER, ".5"},
 		{STRING, "All"},
@@ -156,6 +167,12 @@ func TestLexTapeFile(t *testing.T) {
 		{NUMBER, "500"},
 		{MILLISECONDS, "ms"},
 		{STRING, "All"},
+		{TYPE, "Type"},
+		{STRING, "Double Quote"},
+		{TYPE, "Type"},
+		{STRING, "\"Single\" Quote"},
+		{TYPE, "Type"},
+		{STRING, `"Backtick" 'Quote'`},
 		{COMMENT, " Keys:"},
 		{BACKSPACE, "Backspace"},
 		{BACKSPACE, "Backspace"},
