@@ -1,15 +1,18 @@
 package main
 
 import (
+	"context"
 	_ "embed"
 	"errors"
 	"fmt"
 	"io"
 	"os"
 	"os/exec"
+	"os/signal"
 	"regexp"
 	"runtime/debug"
 	"strings"
+	"syscall"
 
 	version "github.com/hashicorp/go-version"
 	"github.com/spf13/cobra"
@@ -26,12 +29,15 @@ var (
 	// CommitSHA stores the commit SHA of VHS at the time of packaging through -ldflags
 	CommitSHA string
 
-	ttydMinVersion = version.Must(version.NewVersion("1.7.1"))
+	ttydMinVersion = version.Must(version.NewVersion("1.7.2"))
 
+	publish bool
 	rootCmd = &cobra.Command{
-		Use:   "vhs <file>",
-		Short: "Run a given tape file and generates its outputs.",
-		Args:  cobra.MaximumNArgs(1),
+		Use:           "vhs <file>",
+		Short:         "Run a given tape file and generates its outputs.",
+		Args:          cobra.MaximumNArgs(1),
+		SilenceUsage:  true,
+		SilenceErrors: true, // we print our own errors
 		RunE: func(cmd *cobra.Command, args []string) error {
 			err := ensureDependencies()
 			if err != nil {
@@ -57,14 +63,57 @@ var (
 				return errors.New("no input provided")
 			}
 
-			err = Evaluate(string(input), os.Stdout)
+			var output string
+			errs := Evaluate(cmd.Context(), string(input), os.Stdout, func(v *VHS) {
+				output = v.Options.Video.Output.GIF
+			})
+			if len(errs) > 0 {
+				printErrors(os.Stderr, string(input), errs)
+				return errors.New("recording failed")
+			}
+
+			if publish && output != "" {
+				url, err := Publish(cmd.Context(), output)
+				if err != nil {
+					return err
+				}
+				fmt.Println(StringStyle.Render("URL: " + url))
+			}
+
+			return nil
+		},
+	}
+
+	markdown  bool
+	themesCmd = &cobra.Command{
+		Use:   "themes",
+		Short: "List all the available themes, one per line",
+		Args:  cobra.NoArgs,
+		RunE: func(cmd *cobra.Command, args []string) error {
+			var prefix, suffix string
+			if markdown {
+				fmt.Fprintf(cmd.OutOrStdout(), "# Themes\n\n")
+				prefix, suffix = "* `", "`"
+			}
+			themes, err := sortedThemeNames()
 			if err != nil {
 				return err
 			}
+			for _, theme := range themes {
+				fmt.Fprintf(cmd.OutOrStdout(), "%s%s%s\n", prefix, theme, suffix)
+			}
 			return nil
 		},
 	}
 
+	shell     string
+	recordCmd = &cobra.Command{
+		Use:   "record",
+		Short: "Create a new tape file by recording your actions",
+		Args:  cobra.NoArgs,
+		RunE:  Record,
+	}
+
 	newCmd = &cobra.Command{
 		Use:   "new <name>",
 		Short: "Create a new tape file with example tape file contents and documentation",
@@ -109,14 +158,10 @@ var (
 				errs := p.Errors()
 
 				if len(errs) != 0 {
-					lines := strings.Split(string(b), "\n")
 					fmt.Println(ErrorFileStyle.Render(file))
+
 					for _, err := range errs {
-						fmt.Print(LineNumber(err.Token.Line))
-						fmt.Println(lines[err.Token.Line-1])
-						fmt.Print(strings.Repeat(" ", err.Token.Column+ErrorColumnOffset))
-						fmt.Println(Underline(len(err.Token.Literal)), err.Msg)
-						fmt.Println()
+						printParserError(os.Stderr, string(b), err)
 					}
 					valid = false
 				}
@@ -132,18 +177,31 @@ var (
 )
 
 func main() {
-	if err := rootCmd.Execute(); err != nil {
+	ctx, cancel := signal.NotifyContext(
+		context.Background(),
+		os.Interrupt, syscall.SIGTERM,
+	)
+	defer cancel()
+
+	if err := rootCmd.ExecuteContext(ctx); err != nil {
 		fmt.Println(err)
 		os.Exit(1)
 	}
 }
 
 func init() {
+	rootCmd.Flags().BoolVarP(&publish, "publish", "p", false, "publish your GIF to vhs.charm.sh and get a shareable URL")
+	themesCmd.Flags().BoolVar(&markdown, "markdown", false, "output as markdown")
+	_ = themesCmd.Flags().MarkHidden("markdown")
+	recordCmd.Flags().StringVarP(&shell, "shell", "s", "bash", "shell for recording")
 	rootCmd.AddCommand(
+		recordCmd,
 		newCmd,
+		themesCmd,
 		validateCmd,
 		manCmd,
 		serveCmd,
+		publishCmd,
 	)
 	rootCmd.CompletionOptions.HiddenDefaultCmd = true
 
