@@ -95,7 +95,6 @@ Sleep Bar`
 
 func TestParseTapeFile(t *testing.T) {
 	input, err := os.ReadFile("examples/fixtures/all.tape")
-
 	if err != nil {
 		t.Fatal("could not read fixture file")
 	}
@@ -104,6 +103,7 @@ func TestParseTapeFile(t *testing.T) {
 		{Type: OUTPUT, Options: ".gif", Args: "examples/fixtures/all.gif"},
 		{Type: OUTPUT, Options: ".mp4", Args: "examples/fixtures/all.mp4"},
 		{Type: OUTPUT, Options: ".webm", Args: "examples/fixtures/all.webm"},
+		{Type: SET, Options: "Shell", Args: "fish"},
 		{Type: SET, Options: "FontSize", Args: "22"},
 		{Type: SET, Options: "FontFamily", Args: "DejaVu Sans Mono"},
 		{Type: SET, Options: "Height", Args: "600"},
@@ -111,17 +111,22 @@ func TestParseTapeFile(t *testing.T) {
 		{Type: SET, Options: "LetterSpacing", Args: "1"},
 		{Type: SET, Options: "LineHeight", Args: "1.2"},
 		{Type: SET, Options: "Theme", Args: "{ \"name\": \"Whimsy\", \"black\": \"#535178\", \"red\": \"#ef6487\", \"green\": \"#5eca89\", \"yellow\": \"#fdd877\", \"blue\": \"#65aef7\", \"purple\": \"#aa7ff0\", \"cyan\": \"#43c1be\", \"white\": \"#ffffff\", \"brightBlack\": \"#535178\", \"brightRed\": \"#ef6487\", \"brightGreen\": \"#5eca89\", \"brightYellow\": \"#fdd877\", \"brightBlue\": \"#65aef7\", \"brightPurple\": \"#aa7ff0\", \"brightCyan\": \"#43c1be\", \"brightWhite\": \"#ffffff\", \"background\": \"#29283b\", \"foreground\": \"#b3b0d6\", \"selectionBackground\": \"#3d3c58\", \"cursorColor\": \"#b3b0d6\" }"},
+		{Type: SET, Options: "Theme", Args: "Catppuccin Mocha"},
 		{Type: SET, Options: "Padding", Args: "50"},
 		{Type: SET, Options: "Framerate", Args: "60"},
 		{Type: SET, Options: "PlaybackSpeed", Args: "2"},
 		{Type: SET, Options: "TypingSpeed", Args: ".1s"},
+		{Type: SET, Options: "LoopOffset", Args: "60.4%"},
+		{Type: SET, Options: "LoopOffset", Args: "20.99%"},
 		{Type: SLEEP, Options: "", Args: "1s"},
 		{Type: SLEEP, Options: "", Args: "500ms"},
 		{Type: SLEEP, Options: "", Args: ".5s"},
 		{Type: SLEEP, Options: "", Args: "0.5s"},
-		{Type: TYPE, Options: "", Args: "All"},
 		{Type: TYPE, Options: ".5s", Args: "All"},
 		{Type: TYPE, Options: "500ms", Args: "All"},
+		{Type: TYPE, Options: "", Args: "Double Quote"},
+		{Type: TYPE, Options: "", Args: "\"Single\" Quote"},
+		{Type: TYPE, Options: "", Args: `"Backtick" 'Quote'`},
 		{Type: BACKSPACE, Options: "", Args: "1"},
 		{Type: BACKSPACE, Options: "", Args: "2"},
 		{Type: BACKSPACE, Options: "1s", Args: "3"},
@@ -176,5 +181,4 @@ func TestParseTapeFile(t *testing.T) {
 			t.Errorf("Expected command %d to have options %s, got %s", i, expected[i].Options, cmd.Options)
 		}
 	}
-
 }
