@@ -9,10 +9,8 @@ import (
 	"math/rand"
 	"net"
 	"os"
-	"os/signal"
 	"path/filepath"
 	"strconv"
-	"syscall"
 	"time"
 
 	"github.com/caarlos0/env/v6"
@@ -93,20 +91,21 @@ var serveCmd = &cobra.Command{
 						//nolint:gosec
 						rand := rand.Int63n(maxNumber)
 						tempFile := filepath.Join(os.TempDir(), fmt.Sprintf("vhs-%d.gif", rand))
-
-						err = Evaluate(b.String(), s.Stderr(), func(v *VHS) {
+						defer func() { _ = os.Remove(tempFile) }()
+						errs := Evaluate(s.Context(), b.String(), s.Stderr(), func(v *VHS) {
 							v.Options.Video.Output.GIF = tempFile
 							// Disable generating MP4 & WebM.
 							v.Options.Video.Output.MP4 = ""
 							v.Options.Video.Output.WebM = ""
 						})
-						if err != nil {
+
+						if len(errs) > 0 {
+							printErrors(s.Stderr(), b.String(), errs)
 							_ = s.Exit(1)
 						}
 
 						gif, _ := os.ReadFile(tempFile)
 						wish.Print(s, string(gif))
-						_ = os.Remove(tempFile)
 
 						h(s)
 					}
@@ -115,36 +114,40 @@ var serveCmd = &cobra.Command{
 			),
 		)
 		if err != nil {
-			log.Fatalln(err)
+			return err
 		}
 
-		done := make(chan os.Signal, 1)
-		signal.Notify(done, os.Interrupt, syscall.SIGINT, syscall.SIGTERM)
+		// listen
 		log.Printf("Starting SSH server on %s", addr)
+		ls, err := net.Listen("tcp", addr)
+		if err != nil {
+			return fmt.Errorf("failed to listen on %s: %w", addr, err)
+		}
+
+		// drop privileges
+		gid, uid := cfg.GID, cfg.UID
+		if gid != 0 && uid != 0 {
+			log.Printf("Starting server with GID: %d, UID: %d", gid, uid)
+			if err := dropUserPrivileges(gid, uid); err != nil {
+				return err
+			}
+		}
+
+		sch := make(chan error)
 		go func() {
-			ls, err := net.Listen("tcp", addr)
-			if err != nil {
-				log.Fatalf("Failed to listen on %s: %v", addr, err)
-			}
-			gid, uid := cfg.GID, cfg.UID
-			if gid != 0 && uid != 0 {
-				log.Printf("Starting server with GID: %d, UID: %d", gid, uid)
-				if err := dropUserPrivileges(gid, uid); err != nil {
-					log.Fatalln(err)
-				}
-			}
-			if err = s.Serve(ls); err != nil {
-				log.Fatalln(err)
-			}
+			defer close(sch)
+			sch <- s.Serve(ls)
 		}()
 
-		<-done
+		<-cmd.Context().Done()
 		log.Println("Stopping SSH server")
 		ctx, cancel := context.WithTimeout(context.Background(), timeout)
-		defer func() { cancel() }()
+		defer cancel()
 		if err := s.Shutdown(ctx); err != nil {
-			log.Fatalln(err)
+			return err
 		}
-		return nil
+
+		// wait for serve to finish
+		return <-sch
 	},
 }
