@@ -1,5 +1,7 @@
 package main
 
+import "strings"
+
 // Type represents a token's type.
 type TokenType string
 
@@ -11,7 +13,7 @@ type Token struct {
 	Column  int
 }
 
-//nolint:revive
+// Tokens for the VHS language
 const (
 	AT             = "@"
 	EQUAL          = "="
@@ -40,26 +42,31 @@ const (
 	UP             = "UP"
 	TAB            = "TAB"
 	ESCAPE         = "ESCAPE"
-	BEGIN          = "BEGIN"
+	DELETE         = "DELETE"
+	HOME           = "HOME"
+	INSERT         = "INSERT"
 	END            = "END"
 	HIDE           = "HIDE"
+	REQUIRE        = "REQUIRE"
 	SHOW           = "SHOW"
 	OUTPUT         = "OUTPUT"
 	MILLISECONDS   = "MILLISECONDS"
 	SECONDS        = "SECONDS"
 	MINUTES        = "MINUTES"
 	COMMENT        = "COMMENT"
-	FONT_FAMILY    = "FONT_FAMILY"
-	FONT_SIZE      = "FONT_SIZE"
+	SHELL          = "SHELL"
+	FONT_FAMILY    = "FONT_FAMILY" //nolint:revive
+	FONT_SIZE      = "FONT_SIZE"   //nolint:revive
 	FRAMERATE      = "FRAMERATE"
-	PLAYBACK_SPEED = "PLAYBACK_SPEED"
+	PLAYBACK_SPEED = "PLAYBACK_SPEED" //nolint:revive
 	HEIGHT         = "HEIGHT"
 	WIDTH          = "WIDTH"
-	LETTER_SPACING = "LETTER_SPACING"
-	LINE_HEIGHT    = "LINE_HEIGHT"
-	TYPING_SPEED   = "TYPING_SPEED"
+	LETTER_SPACING = "LETTER_SPACING" //nolint:revive
+	LINE_HEIGHT    = "LINE_HEIGHT"    //nolint:revive
+	TYPING_SPEED   = "TYPING_SPEED"   //nolint:revive
 	PADDING        = "PADDING"
 	THEME          = "THEME"
+	LOOP_OFFSET    = "LOOP_OFFSET" //nolint:revive
 )
 
 var keywords = map[string]TokenType{
@@ -81,11 +88,12 @@ var keywords = map[string]TokenType{
 	"Up":            UP,
 	"Tab":           TAB,
 	"Escape":        ESCAPE,
-	"Begin":         BEGIN,
 	"End":           END,
 	"Hide":          HIDE,
+	"Require":       REQUIRE,
 	"Show":          SHOW,
 	"Output":        OUTPUT,
+	"Shell":         SHELL,
 	"FontFamily":    FONT_FAMILY,
 	"FontSize":      FONT_SIZE,
 	"Framerate":     FRAMERATE,
@@ -97,20 +105,42 @@ var keywords = map[string]TokenType{
 	"Padding":       PADDING,
 	"Theme":         THEME,
 	"Width":         WIDTH,
+	"LoopOffset":    LOOP_OFFSET,
 }
 
 // IsSetting returns whether a token is a setting.
 func IsSetting(t TokenType) bool {
 	switch t {
-	case FONT_FAMILY, FONT_SIZE, LETTER_SPACING, LINE_HEIGHT,
+	case SHELL, FONT_FAMILY, FONT_SIZE, LETTER_SPACING, LINE_HEIGHT,
 		FRAMERATE, TYPING_SPEED, THEME, PLAYBACK_SPEED,
-		HEIGHT, WIDTH, PADDING:
+		HEIGHT, WIDTH, PADDING, LOOP_OFFSET:
 		return true
 	default:
 		return false
 	}
 }
 
+// IsCommand returns whether the string is a command
+func IsCommand(t TokenType) bool {
+	switch t {
+	case TYPE, SLEEP,
+		UP, DOWN, RIGHT, LEFT,
+		ENTER, BACKSPACE, DELETE, TAB,
+		ESCAPE, HOME, INSERT, END, CTRL:
+		return true
+	default:
+		return false
+	}
+}
+
+// String converts a token to it's human readable string format.
+func (t TokenType) String() string {
+	if IsCommand(t) || IsSetting(t) {
+		return strings.ToTitle(string(t[0])) + strings.ToLower(string(t[1:]))
+	}
+	return string(t)
+}
+
 // LookupIdentifier returns whether the identifier is a keyword.
 // In `vhs`, there are no _actual_ identifiers, i.e. there are no variables.
 // Instead, identifiers are simply strings (i.e. bare words).
