@@ -24,14 +24,18 @@ func randomPort() int {
 
 // StartTTY starts the ttyd process on the given port.
 func StartTTY(port int) *exec.Cmd {
-	//nolint:gosec
-	cmd := exec.Command(
-		"ttyd", fmt.Sprintf("--port=%d", port),
+	args := []string{
+		fmt.Sprintf("--port=%d", port),
 		"-t", "rendererType=canvas",
 		"-t", "disableResizeOverlay=true",
 		"-t", "cursorBlink=true",
+		"-t", "enableSixel=true",
 		"-t", "customGlyphs=true",
-		"bash", "--login",
-	)
+	}
+
+	args = append(args, defaultShellWithArgs()...)
+
+	//nolint:gosec
+	cmd := exec.Command("ttyd", args...)
 	return cmd
 }
