@@ -49,6 +49,7 @@ type VideoOptions struct {
 	Height          int
 	Padding         int
 	BackgroundColor string
+	StartingFrame   int
 }
 
 const defaultFramerate = 50
@@ -57,6 +58,7 @@ const defaultMaxColors = 256
 const defaultPadding = 72
 const defaultPlaybackSpeed = 1.0
 const defaultWidth = 1200
+const defaultStartingFrame = 1
 
 // DefaultVideoOptions is the set of default options for converting frames
 // to a GIF, which are used if they are not overridden.
@@ -72,6 +74,7 @@ func DefaultVideoOptions() VideoOptions {
 		Padding:         defaultPadding,
 		PlaybackSpeed:   defaultPlaybackSpeed,
 		BackgroundColor: DefaultTheme.Background,
+		StartingFrame:   defaultStartingFrame,
 	}
 }
 
@@ -87,12 +90,15 @@ func MakeGIF(opts VideoOptions) *exec.Cmd {
 	return exec.Command(
 		"ffmpeg", "-y",
 		"-r", fmt.Sprint(opts.Framerate),
+		"-start_number", fmt.Sprint(opts.StartingFrame),
 		"-i", filepath.Join(opts.Input, textFrameFormat),
 		"-r", fmt.Sprint(opts.Framerate),
+		"-start_number", fmt.Sprint(opts.StartingFrame),
 		"-i", filepath.Join(opts.Input, cursorFrameFormat),
 		"-filter_complex",
 		fmt.Sprintf(`[0][1]overlay[merged];[merged]scale=%d:%d:force_original_aspect_ratio=1[scaled];[scaled]fps=%d,setpts=PTS/%f[speed];[speed]pad=%d:%d:(ow-iw)/2:(oh-ih)/2:%s[padded];[padded]fillborders=left=%d:right=%d:top=%d:bottom=%d:mode=fixed:color=%s[bordered];[bordered]split[a][b];[a]palettegen=max_colors=256[p];[b][p]paletteuse[out]`,
-			opts.Width-2*opts.Padding, opts.Height-2*opts.Padding,
+			opts.Width-(opts.Padding+opts.Padding),
+			opts.Height-(opts.Padding+opts.Padding),
 			opts.Framerate, opts.PlaybackSpeed,
 			opts.Width, opts.Height,
 			opts.BackgroundColor,
@@ -116,12 +122,15 @@ func MakeWebM(opts VideoOptions) *exec.Cmd {
 	return exec.Command(
 		"ffmpeg", "-y",
 		"-r", fmt.Sprint(opts.Framerate),
+		"-start_number", fmt.Sprint(opts.StartingFrame),
 		"-i", filepath.Join(opts.Input, textFrameFormat),
 		"-r", fmt.Sprint(opts.Framerate),
+		"-start_number", fmt.Sprint(opts.StartingFrame),
 		"-i", filepath.Join(opts.Input, cursorFrameFormat),
 		"-filter_complex",
 		fmt.Sprintf(`[0][1]overlay,scale=%d:%d:force_original_aspect_ratio=1,fps=%d,setpts=PTS/%f,pad=%d:%d:(ow-iw)/2:(oh-ih)/2:%s,fillborders=left=%d:right=%d:top=%d:bottom=%d:mode=fixed:color=%s`,
-			opts.Width-2*opts.Padding, opts.Height-2*opts.Padding,
+			opts.Width-(opts.Padding+opts.Padding),
+			opts.Height-(opts.Padding+opts.Padding),
 			opts.Framerate, opts.PlaybackSpeed,
 			opts.Width, opts.Height,
 			opts.BackgroundColor,
@@ -148,12 +157,15 @@ func MakeMP4(opts VideoOptions) *exec.Cmd {
 	return exec.Command(
 		"ffmpeg", "-y",
 		"-r", fmt.Sprint(opts.Framerate),
+		"-start_number", fmt.Sprint(opts.StartingFrame),
 		"-i", filepath.Join(opts.Input, textFrameFormat),
 		"-r", fmt.Sprint(opts.Framerate),
+		"-start_number", fmt.Sprint(opts.StartingFrame),
 		"-i", filepath.Join(opts.Input, cursorFrameFormat),
 		"-filter_complex",
 		fmt.Sprintf(`[0][1]overlay,scale=%d:%d:force_original_aspect_ratio=1,fps=%d,setpts=PTS/%f,pad=%d:%d:(ow-iw)/2:(oh-ih)/2:%s,fillborders=left=%d:right=%d:top=%d:bottom=%d:mode=fixed:color=%s`,
-			opts.Width-2*opts.Padding, opts.Height-2*opts.Padding,
+			opts.Width-(opts.Padding+opts.Padding),
+			opts.Height-(opts.Padding+opts.Padding),
 			opts.Framerate, opts.PlaybackSpeed,
 			opts.Width, opts.Height,
 			opts.BackgroundColor,
